@@ -453,7 +453,7 @@ network_error (SoupMessage *msg, GtkBuilder *ui)
 						      _("There has been a network error while sending the report. "
 							"Do you want to save this report and send it later?"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  "%s", _("Please ensure that your internet connection is active "
+						  "%s", _("Please ensure that your Internet connection is active "
 							  "and working correctly."));
 	res = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -1057,6 +1057,12 @@ on_send_clicked (GtkWidget *button, gpointer data)
 			return;
 	}
 
+	/* hide the send button immediately so that the user can't click
+	 * it more than once (this will create multiple bugs).
+	 */
+	gtk_widget_hide (GTK_WIDGET (
+			gtk_builder_get_object (ui, "send-button")));
+
 	gtk_widget_show (GTK_WIDGET (
 			gtk_builder_get_object (ui, "progressbar")));
 	gtk_widget_hide (GTK_WIDGET (
